You can subscribe to this list here.
| 2002 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(1) |
Oct
(122) |
Nov
(152) |
Dec
(69) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2003 |
Jan
(6) |
Feb
(25) |
Mar
(73) |
Apr
(82) |
May
(24) |
Jun
(25) |
Jul
(10) |
Aug
(11) |
Sep
(10) |
Oct
(54) |
Nov
(203) |
Dec
(182) |
| 2004 |
Jan
(307) |
Feb
(305) |
Mar
(430) |
Apr
(312) |
May
(187) |
Jun
(342) |
Jul
(487) |
Aug
(637) |
Sep
(336) |
Oct
(373) |
Nov
(441) |
Dec
(210) |
| 2005 |
Jan
(385) |
Feb
(480) |
Mar
(636) |
Apr
(544) |
May
(679) |
Jun
(625) |
Jul
(810) |
Aug
(838) |
Sep
(634) |
Oct
(521) |
Nov
(965) |
Dec
(543) |
| 2006 |
Jan
(494) |
Feb
(431) |
Mar
(546) |
Apr
(411) |
May
(406) |
Jun
(322) |
Jul
(256) |
Aug
(401) |
Sep
(345) |
Oct
(542) |
Nov
(308) |
Dec
(481) |
| 2007 |
Jan
(427) |
Feb
(326) |
Mar
(367) |
Apr
(255) |
May
(244) |
Jun
(204) |
Jul
(223) |
Aug
(231) |
Sep
(354) |
Oct
(374) |
Nov
(497) |
Dec
(362) |
| 2008 |
Jan
(322) |
Feb
(482) |
Mar
(658) |
Apr
(422) |
May
(476) |
Jun
(396) |
Jul
(455) |
Aug
(267) |
Sep
(280) |
Oct
(253) |
Nov
(232) |
Dec
(304) |
| 2009 |
Jan
(486) |
Feb
(470) |
Mar
(458) |
Apr
(423) |
May
(696) |
Jun
(461) |
Jul
(551) |
Aug
(575) |
Sep
(134) |
Oct
(110) |
Nov
(157) |
Dec
(102) |
| 2010 |
Jan
(226) |
Feb
(86) |
Mar
(147) |
Apr
(117) |
May
(107) |
Jun
(203) |
Jul
(193) |
Aug
(238) |
Sep
(300) |
Oct
(246) |
Nov
(23) |
Dec
(75) |
| 2011 |
Jan
(133) |
Feb
(195) |
Mar
(315) |
Apr
(200) |
May
(267) |
Jun
(293) |
Jul
(353) |
Aug
(237) |
Sep
(278) |
Oct
(611) |
Nov
(274) |
Dec
(260) |
| 2012 |
Jan
(303) |
Feb
(391) |
Mar
(417) |
Apr
(441) |
May
(488) |
Jun
(655) |
Jul
(590) |
Aug
(610) |
Sep
(526) |
Oct
(478) |
Nov
(359) |
Dec
(372) |
| 2013 |
Jan
(467) |
Feb
(226) |
Mar
(391) |
Apr
(281) |
May
(299) |
Jun
(252) |
Jul
(311) |
Aug
(352) |
Sep
(481) |
Oct
(571) |
Nov
(222) |
Dec
(231) |
| 2014 |
Jan
(185) |
Feb
(329) |
Mar
(245) |
Apr
(238) |
May
(281) |
Jun
(399) |
Jul
(382) |
Aug
(500) |
Sep
(579) |
Oct
(435) |
Nov
(487) |
Dec
(256) |
| 2015 |
Jan
(338) |
Feb
(357) |
Mar
(330) |
Apr
(294) |
May
(191) |
Jun
(108) |
Jul
(142) |
Aug
(261) |
Sep
(190) |
Oct
(54) |
Nov
(83) |
Dec
(22) |
| 2016 |
Jan
(49) |
Feb
(89) |
Mar
(33) |
Apr
(50) |
May
(27) |
Jun
(34) |
Jul
(53) |
Aug
(53) |
Sep
(98) |
Oct
(206) |
Nov
(93) |
Dec
(53) |
| 2017 |
Jan
(65) |
Feb
(82) |
Mar
(102) |
Apr
(86) |
May
(187) |
Jun
(67) |
Jul
(23) |
Aug
(93) |
Sep
(65) |
Oct
(45) |
Nov
(35) |
Dec
(17) |
| 2018 |
Jan
(26) |
Feb
(35) |
Mar
(38) |
Apr
(32) |
May
(8) |
Jun
(43) |
Jul
(27) |
Aug
(30) |
Sep
(43) |
Oct
(42) |
Nov
(38) |
Dec
(67) |
| 2019 |
Jan
(32) |
Feb
(37) |
Mar
(53) |
Apr
(64) |
May
(49) |
Jun
(18) |
Jul
(14) |
Aug
(53) |
Sep
(25) |
Oct
(30) |
Nov
(49) |
Dec
(31) |
| 2020 |
Jan
(87) |
Feb
(45) |
Mar
(37) |
Apr
(51) |
May
(99) |
Jun
(36) |
Jul
(11) |
Aug
(14) |
Sep
(20) |
Oct
(24) |
Nov
(40) |
Dec
(23) |
| 2021 |
Jan
(14) |
Feb
(53) |
Mar
(85) |
Apr
(15) |
May
(19) |
Jun
(3) |
Jul
(14) |
Aug
(1) |
Sep
(57) |
Oct
(73) |
Nov
(56) |
Dec
(22) |
| 2022 |
Jan
(3) |
Feb
(22) |
Mar
(6) |
Apr
(55) |
May
(46) |
Jun
(39) |
Jul
(15) |
Aug
(9) |
Sep
(11) |
Oct
(34) |
Nov
(20) |
Dec
(36) |
| 2023 |
Jan
(79) |
Feb
(41) |
Mar
(99) |
Apr
(169) |
May
(48) |
Jun
(16) |
Jul
(16) |
Aug
(57) |
Sep
(19) |
Oct
|
Nov
|
Dec
|
| S | M | T | W | T | F | S |
|---|---|---|---|---|---|---|
|
|
|
|
1
(9) |
2
(7) |
3
(15) |
4
(14) |
|
5
(12) |
6
(18) |
7
(16) |
8
(13) |
9
(14) |
10
(20) |
11
(26) |
|
12
(14) |
13
(25) |
14
(20) |
15
(15) |
16
(14) |
17
(13) |
18
(12) |
|
19
(8) |
20
(16) |
21
(15) |
22
(37) |
23
(15) |
24
(18) |
25
(12) |
|
26
(8) |
27
(13) |
28
(12) |
|
|
|
|
|
From: Robert W. <rj...@du...> - 2006-02-04 21:49:15
|
Hi all,
Valgrind still has some nested functions in m_debuginfo/symtypes.c
(newvar and genstring). What's the policy with respect to nested
functions? Would you all be OK if I recoded this a little to remove the
nesting? I only noticed them because my compile threw up this warning:
m_debuginfo/symtypes.c: In function 'vgPlain_describe_addr':
m_debuginfo/symtypes.c:765: warning: no previous prototype for 'newvar'
m_debuginfo/symtypes.c:986: warning: no previous prototype for 'genstri=
ng'
This isn't a problem for me, as such, but I have a vague recollection of
people on the list reporting that this caused compile problems on older
versions of gcc.
Regards,
Robert.
--=20
Robert Walsh
Amalgamated Durables, Inc. - "We don't make the things you buy."
Email: rj...@du...
|
|
From: <sv...@va...> - 2006-02-04 15:43:19
|
Author: sewardj
Date: 2006-02-04 15:43:14 +0000 (Sat, 04 Feb 2006)
New Revision: 5610
Log:
Add a check for fsincos.
Modified:
trunk/memcheck/tests/x86/fprem.c
trunk/memcheck/tests/x86/fprem.stdout.exp
Modified: trunk/memcheck/tests/x86/fprem.c
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/tests/x86/fprem.c (rev 0)
+++ trunk/memcheck/tests/x86/fprem.c 2006-02-04 15:26:11 UTC (rev 5609)
@@ -0,0 +1,42 @@
+
+/* Marginally test fprem/fprem1; these are hard to check otherwise */
+
+#include <stdio.h>
+
+double do_fprem ( void )
+{
+ double res;
+ __asm__ __volatile__(
+ "ffree %%st(0)\n\t"
+ "ffree %%st(1)\n\t"
+ "fldpi\n\t"
+ "fldln2\n\t"
+ "fprem\n\t"
+ "fstpl 0(%0)"
+ : : "r"(&res) =20
+ );
+ return res;
+}
+
+double do_fprem1 ( void )
+{
+ double res;
+ __asm__ __volatile__(
+ "ffree %%st(0)\n\t"
+ "ffree %%st(1)\n\t"
+ "fldpi\n\t"
+ "fldln2\n\t"
+ "fprem1\n\t"
+ "fstpl 0(%0)"
+ : : "r"(&res) =20
+ );
+ return res;
+}
+
+int main ( void )
+{
+ __asm__ __volatile__("finit");
+ printf("fprem %f\n", do_fprem());
+ printf("fprem1 %f\n", do_fprem1());
+ return 0;
+}
Added: trunk/memcheck/tests/x86/fprem.stderr.exp
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
Added: trunk/memcheck/tests/x86/fprem.stdout.exp
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/tests/x86/fprem.stdout.exp (re=
v 0)
+++ trunk/memcheck/tests/x86/fprem.stdout.exp 2006-02-04 15:26:11 UTC (re=
v 5609)
@@ -0,0 +1,2 @@
+fprem 0.693147
+fprem1 0.693147
Added: trunk/memcheck/tests/x86/fprem.vgtest
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/tests/x86/fprem.vgtest (rev 0)
+++ trunk/memcheck/tests/x86/fprem.vgtest 2006-02-04 15:26:11 UTC (rev 56=
09)
@@ -0,0 +1,2 @@
+vgopts: -q
+prog: fprem
Added: trunk/memcheck/tests/x86/more_x86_fp.c
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/tests/x86/more_x86_fp.c (rev 0=
)
+++ trunk/memcheck/tests/x86/more_x86_fp.c 2006-02-04 15:26:11 UTC (rev 5=
609)
@@ -0,0 +1,263 @@
+
+/* Derived from: */
+
+/*
+ * x86 CPU test
+ *
+ * Copyright (c) 2003 Fabrice Bellard
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <inttypes.h>
+#include <math.h>
+
+/**********************************************/
+
+void test_fops(double a, double b)
+{
+ printf("a=3D%f b=3D%f a+b=3D%f\n", a, b, a + b);
+ printf("a=3D%f b=3D%f a-b=3D%f\n", a, b, a - b);
+ printf("a=3D%f b=3D%f a*b=3D%f\n", a, b, a * b);
+ printf("a=3D%f b=3D%f a/b=3D%f\n", a, b, a / b);
+ printf("a=3D%f b=3D%f fmod(a, b)=3D%f\n", a, b, fmod(a, b));
+ printf("a=3D%f sqrt(a)=3D%f\n", a, sqrt(a));
+ printf("a=3D%f sin(a)=3D%f\n", a, sin(a));
+ printf("a=3D%f cos(a)=3D%f\n", a, cos(a));
+ printf("a=3D%f tan(a)=3D%f\n", a, tan(a));
+ printf("a=3D%f log(a)=3D%f\n", a, log(a));
+ printf("a=3D%f exp(a)=3D%f\n", a, exp(a));
+ printf("a=3D%f b=3D%f atan2(a, b)=3D%f\n", a, b, atan2(a, b));
+ /* just to test some op combining */
+ printf("a=3D%f asin(sin(a))=3D%f\n", a, asin(sin(a)));
+ printf("a=3D%f acos(cos(a))=3D%f\n", a, acos(cos(a)));
+ printf("a=3D%f atan(tan(a))=3D%f\n", a, atan(tan(a)));
+}
+#define CC_C 0x0001
+#define CC_P 0x0004
+#define CC_A 0x0010
+#define CC_Z 0x0040
+#define CC_S 0x0080
+#define CC_O 0x0800
+
+
+void test_fcmp(double a, double b)
+{
+ printf("(%f<%f)=3D%d\n",
+ a, b, a < b);
+ printf("(%f<=3D%f)=3D%d\n",
+ a, b, a <=3D b);
+ printf("(%f=3D=3D%f)=3D%d\n",
+ a, b, a =3D=3D b);
+ printf("(%f>%f)=3D%d\n",
+ a, b, a > b);
+ printf("(%f<=3D%f)=3D%d\n",
+ a, b, a >=3D b);
+ {
+ unsigned int eflags;
+ /* test f(u)comi instruction */
+ asm("fcomi %2, %1\n"
+ "pushf\n"
+ "pop %0\n"
+ : "=3Dr" (eflags)
+ : "t" (a), "u" (b));
+ printf("fcomi(%f %f)=3D%08x\n", a, b, eflags & (CC_Z | CC_P | CC=
_C));
+ }
+}
+
+void test_fcvt(double a)
+{
+ float fa;
+ long double la;
+ int16_t fpuc;
+ int i;
+ int64_t lla;
+ int ia;
+ int16_t wa;
+ double ra;
+
+ fa =3D a;
+ la =3D a;
+ printf("(float)%f =3D %f\n", a, fa);
+ printf("(long double)%f =3D %Lf\n", a, la);
+ printf("a=3D%016Lx\n", *(long long *)&a);
+ printf("la=3D%016Lx %04x\n", *(long long *)&la,=20
+ *(unsigned short *)((char *)(&la) + 8));
+
+ /* test all roundings */
+ asm volatile ("fstcw %0" : "=3Dm" (fpuc));
+ for(i=3D0;i<4;i++) {
+ int16_t tmp =3D (fpuc & ~0x0c00) | (i << 10);
+ asm volatile ("fldcw %0" : : "m" (tmp));
+ asm volatile ("fist %0" : "=3Dm" (wa) : "t" (a));
+ asm volatile ("fistl %0" : "=3Dm" (ia) : "t" (a));
+ asm volatile ("fistpll %0" : "=3Dm" (lla) : "t" (a) : "st");
+ asm volatile ("frndint ; fstl %0" : "=3Dm" (ra) : "t" (a));
+ asm volatile ("fldcw %0" : : "m" (fpuc));
+ printf("(short)a =3D %d\n", wa);
+ printf("(int)a =3D %d\n", ia);
+ printf("(int64_t)a =3D %Ld\n", lla);
+ printf("rint(a) =3D %f\n", ra);
+ }
+}
+
+#define TEST(N) \
+ asm("fld" #N : "=3Dt" (a)); \
+ printf("fld" #N "=3D %f\n", a);
+
+void test_fconst(void)
+{
+ double a;
+ TEST(1);
+ TEST(l2t);
+ TEST(l2e);
+ TEST(pi);
+ TEST(lg2);
+ TEST(ln2);
+ TEST(z);
+}
+
+void test_fbcd(double a)
+{
+ unsigned short bcd[5];
+ double b;
+
+ asm("fbstp %0" : "=3Dm" (bcd[0]) : "t" (a) : "st");
+ asm("fbld %1" : "=3Dt" (b) : "m" (bcd[0]));
+ printf("a=3D%f bcd=3D%04x%04x%04x%04x%04x b=3D%f\n",=20
+ a, bcd[4], bcd[3], bcd[2], bcd[1], bcd[0], b);
+}
+
+#define TEST_ENV(env, save, restore)\
+{\
+ memset((env), 0xaa, sizeof(*(env)));\
+ for(i=3D0;i<5;i++)\
+ asm volatile ("fldl %0" : : "m" (dtab[i]));\
+ asm(save " %0\n" : : "m" (*(env)));\
+ asm(restore " %0\n": : "m" (*(env)));\
+ for(i=3D0;i<5;i++)\
+ asm volatile ("fstpl %0" : "=3Dm" (rtab[i]));\
+ for(i=3D0;i<5;i++)\
+ printf("res[%d]=3D%f\n", i, rtab[i]);\
+ printf("fpuc=3D%04x fpus=3D%04x fptag=3D%04x\n",\
+ (env)->fpuc,\
+ (env)->fpus & 0xff00,\
+ (env)->fptag);\
+}
+
+void test_fenv(void)
+{
+ struct __attribute__((packed)) {
+ uint16_t fpuc;
+ uint16_t dummy1;
+ uint16_t fpus;
+ uint16_t dummy2;
+ uint16_t fptag;
+ uint16_t dummy3;
+ uint32_t ignored[4];
+ long double fpregs[8];
+ } float_env32;
+ struct __attribute__((packed)) {
+ uint16_t fpuc;
+ uint16_t fpus;
+ uint16_t fptag;
+ uint16_t ignored[4];
+ long double fpregs[8];
+ } float_env16;
+ double dtab[8];
+ double rtab[8];
+ int i;
+
+ for(i=3D0;i<8;i++)
+ dtab[i] =3D i + 1;
+
+ TEST_ENV(&float_env16, "data16 fnstenv", "data16 fldenv");
+ TEST_ENV(&float_env16, "data16 fnsave", "data16 frstor");
+ TEST_ENV(&float_env32, "fnstenv", "fldenv");
+ TEST_ENV(&float_env32, "fnsave", "frstor");
+
+ /* test for ffree */
+ for(i=3D0;i<5;i++)
+ asm volatile ("fldl %0" : : "m" (dtab[i]));
+ asm volatile("ffree %st(2)");
+ asm volatile ("fnstenv %0\n" : : "m" (float_env32));
+ asm volatile ("fninit");
+ printf("fptag=3D%04x\n", float_env32.fptag);
+}
+
+
+#define TEST_FCMOV(a, b, eflags, CC)\
+{\
+ double res;\
+ asm("push %3\n"\
+ "popf\n"\
+ "fcmov" CC " %2, %0\n"\
+ : "=3Dt" (res)\
+ : "0" (a), "u" (b), "g" (eflags));\
+ printf("fcmov%s eflags=3D0x%04x-> %f\n", \
+ CC, eflags, res);\
+}
+
+void test_fcmov(void)
+{
+ double a, b;
+ int eflags, i;
+
+ a =3D 1.0;
+ b =3D 2.0;
+ for(i =3D 0; i < 4; i++) {
+ eflags =3D 0;
+ if (i & 1)
+ eflags |=3D CC_C;
+ if (i & 2)
+ eflags |=3D CC_Z;
+ TEST_FCMOV(a, b, eflags, "b");
+ TEST_FCMOV(a, b, eflags, "e");
+ TEST_FCMOV(a, b, eflags, "be");
+ TEST_FCMOV(a, b, eflags, "nb");
+ TEST_FCMOV(a, b, eflags, "ne");
+ TEST_FCMOV(a, b, eflags, "nbe");
+ }
+ TEST_FCMOV(a, b, 0, "u");
+ TEST_FCMOV(a, b, CC_P, "u");
+ TEST_FCMOV(a, b, 0, "nu");
+ TEST_FCMOV(a, b, CC_P, "nu");
+}
+
+void test_floats(void)
+{
+ test_fops(2, 3);
+ test_fops(1.4, -5);
+ test_fcmp(2, -1);
+ test_fcmp(2, 2);
+ test_fcmp(2, 3);
+ test_fcvt(0.5);
+ test_fcvt(-0.5);
+ test_fcvt(1.0/7.0);
+ test_fcvt(-1.0/9.0);
+ test_fcvt(32768);
+ test_fcvt(-1e20);
+ test_fconst();
+}
+
+int main ( void )
+{
+ test_floats();
+ return 0;
+}
Added: trunk/memcheck/tests/x86/more_x86_fp.stderr.exp
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
Added: trunk/memcheck/tests/x86/more_x86_fp.stdout.exp
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/tests/x86/more_x86_fp.stdout.exp =
(rev 0)
+++ trunk/memcheck/tests/x86/more_x86_fp.stdout.exp 2006-02-04 15:26:11 U=
TC (rev 5609)
@@ -0,0 +1,175 @@
+a=3D2.000000 b=3D3.000000 a+b=3D5.000000
+a=3D2.000000 b=3D3.000000 a-b=3D-1.000000
+a=3D2.000000 b=3D3.000000 a*b=3D6.000000
+a=3D2.000000 b=3D3.000000 a/b=3D0.666667
+a=3D2.000000 b=3D3.000000 fmod(a, b)=3D2.000000
+a=3D2.000000 sqrt(a)=3D1.414214
+a=3D2.000000 sin(a)=3D0.909297
+a=3D2.000000 cos(a)=3D-0.416147
+a=3D2.000000 tan(a)=3D-2.185040
+a=3D2.000000 log(a)=3D0.693147
+a=3D2.000000 exp(a)=3D7.389056
+a=3D2.000000 b=3D3.000000 atan2(a, b)=3D0.588003
+a=3D2.000000 asin(sin(a))=3D1.141593
+a=3D2.000000 acos(cos(a))=3D2.000000
+a=3D2.000000 atan(tan(a))=3D-1.141593
+a=3D1.400000 b=3D-5.000000 a+b=3D-3.600000
+a=3D1.400000 b=3D-5.000000 a-b=3D6.400000
+a=3D1.400000 b=3D-5.000000 a*b=3D-7.000000
+a=3D1.400000 b=3D-5.000000 a/b=3D-0.280000
+a=3D1.400000 b=3D-5.000000 fmod(a, b)=3D1.400000
+a=3D1.400000 sqrt(a)=3D1.183216
+a=3D1.400000 sin(a)=3D0.985450
+a=3D1.400000 cos(a)=3D0.169967
+a=3D1.400000 tan(a)=3D5.797884
+a=3D1.400000 log(a)=3D0.336472
+a=3D1.400000 exp(a)=3D4.055200
+a=3D1.400000 b=3D-5.000000 atan2(a, b)=3D2.868584
+a=3D1.400000 asin(sin(a))=3D1.400000
+a=3D1.400000 acos(cos(a))=3D1.400000
+a=3D1.400000 atan(tan(a))=3D1.400000
+(2.000000<-1.000000)=3D0
+(2.000000<=3D-1.000000)=3D0
+(2.000000=3D=3D-1.000000)=3D0
+(2.000000>-1.000000)=3D1
+(2.000000<=3D-1.000000)=3D1
+fcomi(2.000000 -1.000000)=3D00000000
+(2.000000<2.000000)=3D0
+(2.000000<=3D2.000000)=3D1
+(2.000000=3D=3D2.000000)=3D1
+(2.000000>2.000000)=3D0
+(2.000000<=3D2.000000)=3D1
+fcomi(2.000000 2.000000)=3D00000040
+(2.000000<3.000000)=3D1
+(2.000000<=3D3.000000)=3D1
+(2.000000=3D=3D3.000000)=3D0
+(2.000000>3.000000)=3D0
+(2.000000<=3D3.000000)=3D0
+fcomi(2.000000 3.000000)=3D00000001
+(float)0.500000 =3D 0.500000
+(long double)0.500000 =3D 0.500000
+a=3D3fe0000000000000
+la=3D8000000000000000 3ffe
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D 0.000000
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D 0.000000
+(short)a =3D 1
+(int)a =3D 1
+(int64_t)a =3D 1
+rint(a) =3D 1.000000
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D 0.000000
+(float)-0.500000 =3D -0.500000
+(long double)-0.500000 =3D -0.500000
+a=3Dbfe0000000000000
+la=3D8000000000000000 bffe
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D -0.000000
+(short)a =3D -1
+(int)a =3D -1
+(int64_t)a =3D -1
+rint(a) =3D -1.000000
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D -0.000000
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D -0.000000
+(float)0.142857 =3D 0.142857
+(long double)0.142857 =3D 0.142857
+a=3D3fc2492492492492
+la=3D9249249249249000 3ffc
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D 0.000000
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D 0.000000
+(short)a =3D 1
+(int)a =3D 1
+(int64_t)a =3D 1
+rint(a) =3D 1.000000
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D 0.000000
+(float)-0.111111 =3D -0.111111
+(long double)-0.111111 =3D -0.111111
+a=3Dbfbc71c71c71c71c
+la=3De38e38e38e38e000 bffb
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D -0.000000
+(short)a =3D -1
+(int)a =3D -1
+(int64_t)a =3D -1
+rint(a) =3D -1.000000
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D -0.000000
+(short)a =3D 0
+(int)a =3D 0
+(int64_t)a =3D 0
+rint(a) =3D -0.000000
+(float)32768.000000 =3D 32768.000000
+(long double)32768.000000 =3D 32768.000000
+a=3D40e0000000000000
+la=3D8000000000000000 400e
+(short)a =3D -32768
+(int)a =3D 32768
+(int64_t)a =3D 32768
+rint(a) =3D 32768.000000
+(short)a =3D -32768
+(int)a =3D 32768
+(int64_t)a =3D 32768
+rint(a) =3D 32768.000000
+(short)a =3D -32768
+(int)a =3D 32768
+(int64_t)a =3D 32768
+rint(a) =3D 32768.000000
+(short)a =3D -32768
+(int)a =3D 32768
+(int64_t)a =3D 32768
+rint(a) =3D 32768.000000
+(float)-100000000000000000000.000000 =3D -100000002004087734272.000000
+(long double)-100000000000000000000.000000 =3D -100000000000000000000.00=
0000
+a=3Dc415af1d78b58c40
+la=3Dad78ebc5ac620000 c041
+(short)a =3D -32768
+(int)a =3D -2147483648
+(int64_t)a =3D -9223372036854775808
+rint(a) =3D -100000000000000000000.000000
+(short)a =3D -32768
+(int)a =3D -2147483648
+(int64_t)a =3D -9223372036854775808
+rint(a) =3D -100000000000000000000.000000
+(short)a =3D -32768
+(int)a =3D -2147483648
+(int64_t)a =3D -9223372036854775808
+rint(a) =3D -100000000000000000000.000000
+(short)a =3D -32768
+(int)a =3D -2147483648
+(int64_t)a =3D -9223372036854775808
+rint(a) =3D -100000000000000000000.000000
+fld1=3D 1.000000
+fldl2t=3D 3.321928
+fldl2e=3D 1.442695
+fldpi=3D 3.141593
+fldlg2=3D 0.301030
+fldln2=3D 0.693147
+fldz=3D 0.000000
Added: trunk/memcheck/tests/x86/more_x86_fp.vgtest
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/tests/x86/more_x86_fp.vgtest (=
rev 0)
+++ trunk/memcheck/tests/x86/more_x86_fp.vgtest 2006-02-04 15:26:11 UTC (=
rev 5609)
@@ -0,0 +1,2 @@
+vgopts: -q
+prog: more_x86_fp
|
|
From: <sv...@va...> - 2006-02-04 15:25:27
|
Author: sewardj
Date: 2006-02-04 15:25:23 +0000 (Sat, 04 Feb 2006)
New Revision: 5608
Log:
Tidy up a couple more x86-related primops following rounding changes.
Modified:
trunk/memcheck/mc_translate.c
Modified: trunk/memcheck/mc_translate.c
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/mc_translate.c 2006-02-03 22:55:04 UTC (rev 5607)
+++ trunk/memcheck/mc_translate.c 2006-02-04 15:25:23 UTC (rev 5608)
@@ -1650,11 +1650,6 @@
IROp op,
IRAtom* atom1, IRAtom* atom2, IRAtom* atom3 )
{
- IRType and_or_ty;
- IRAtom* (*uifu) (MCEnv*, IRAtom*, IRAtom*);
- IRAtom* (*difd) (MCEnv*, IRAtom*, IRAtom*);
- IRAtom* (*improve) (MCEnv*, IRAtom*, IRAtom*);
-
IRAtom* vatom1 =3D expr2vbits( mce, atom1 );
IRAtom* vatom2 =3D expr2vbits( mce, atom2 );
IRAtom* vatom3 =3D expr2vbits( mce, atom3 );
@@ -1681,8 +1676,14 @@
case Iop_Yl2xF64:
case Iop_Yl2xp1F64:
case Iop_AtanF64:
+ case Iop_PRemF64:
+ case Iop_PRem1F64:
/* I32(rm) x F64 x F64 -> F64 */
return mkLazy3(mce, Ity_I64, vatom1, vatom2, vatom3);
+ case Iop_PRemC3210F64:
+ case Iop_PRem1C3210F64:
+ /* I32(rm) x F64 x F64 -> I32 */
+ return mkLazy3(mce, Ity_I32, vatom1, vatom2, vatom3);
default:
ppIROp(op);
VG_(tool_panic)("memcheck:expr2vbits_Triop");
@@ -2018,8 +2019,6 @@
/* I32(rm) x I64/F64 -> I64/F64 */
return mkLazy2(mce, Ity_I64, vatom1, vatom2);
=20
- case Iop_PRemC3210F64: case Iop_PRem1C3210F64:
- /* Takes two F64 args. */
case Iop_F64toI32:
case Iop_F64toF32:
/* First arg is I32 (rounding mode), second is F64 (data). */
@@ -2029,10 +2028,6 @@
/* First arg is I32 (rounding mode), second is F64 (data). */
return mkLazy2(mce, Ity_I16, vatom1, vatom2);
=20
- case Iop_PRemF64:
- case Iop_PRem1F64:
- return mkLazy2(mce, Ity_I64, vatom1, vatom2);
-
case Iop_CmpF64:
return mkLazy2(mce, Ity_I32, vatom1, vatom2);
=20
|
|
From: <sv...@va...> - 2006-02-04 15:24:06
|
Author: sewardj
Date: 2006-02-04 15:24:00 +0000 (Sat, 04 Feb 2006)
New Revision: 1566
Log:
Make the CSE pass more aggressive. It now commons up Mux0X and GetI
expressions too. This generates somewhat better FP code on x86 since
it removes more redundant artefacts from the x87 FP stack simulation.
Unfortunately commoning up GetIs complicates CSEs, since it is now
possible that "available expressions" collected by the CSEr will
become invalidated by writes to the guest state as we work through the
block. So there is additional code to check for this case.
Some supporting functions (getAliasingRelation_IC and
getAliasingRelation_II) have been moved earlier in the file.
Modified:
trunk/priv/ir/iropt.c
trunk/priv/ir/iropt.h
Modified: trunk/priv/ir/iropt.c
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/priv/ir/iropt.c 2006-02-04 15:20:13 UTC (rev 1565)
+++ trunk/priv/ir/iropt.c 2006-02-04 15:24:00 UTC (rev 1566)
@@ -2030,6 +2030,119 @@
=20
=20
/*---------------------------------------------------------------*/
+/*--- Determination of guest state aliasing relationships ---*/
+/*---------------------------------------------------------------*/
+
+/* These are helper functions for CSE and GetI/PutI transformations.
+
+ Determine, to the extent possible, the relationship between two
+ guest state accesses. The possible outcomes are:
+
+ * Exact alias. These two accesses denote precisely the same
+ piece of the guest state.
+
+ * Definitely no alias. These two accesses are guaranteed not to
+ overlap any part of the guest state.
+
+ * Unknown -- if neither of the above can be established.
+
+ If in doubt, return Unknown. */
+
+typedef
+ enum { ExactAlias, NoAlias, UnknownAlias }
+ GSAliasing;
+
+
+/* Produces the alias relation between an indexed guest
+ state access and a non-indexed access. */
+
+static
+GSAliasing getAliasingRelation_IC ( IRArray* descr1, IRExpr* ix1,
+ Int offset2, IRType ty2 )
+{
+ UInt minoff1, maxoff1, minoff2, maxoff2;
+
+ getArrayBounds( descr1, &minoff1, &maxoff1 );
+ minoff2 =3D offset2;
+ maxoff2 =3D minoff2 + sizeofIRType(ty2) - 1;
+
+ if (maxoff1 < minoff2 || maxoff2 < minoff1)
+ return NoAlias;
+
+ /* Could probably do better here if required. For the moment
+ however just claim not to know anything more. */
+ return UnknownAlias;
+}
+
+
+/* Produces the alias relation between two indexed guest state
+ accesses. */
+
+static
+GSAliasing getAliasingRelation_II (=20
+ IRArray* descr1, IRExpr* ix1, Int bias1,
+ IRArray* descr2, IRExpr* ix2, Int bias2
+ )
+{
+ UInt minoff1, maxoff1, minoff2, maxoff2;
+ Int iters;
+
+ /* First try hard to show they don't alias. */
+ getArrayBounds( descr1, &minoff1, &maxoff1 );
+ getArrayBounds( descr2, &minoff2, &maxoff2 );
+ if (maxoff1 < minoff2 || maxoff2 < minoff1)
+ return NoAlias;
+
+ /* So the two arrays at least partially overlap. To get any
+ further we'll have to be sure that the descriptors are
+ identical. */
+ if (!eqIRArray(descr1, descr2))
+ return UnknownAlias;
+
+ /* The descriptors are identical. Now the only difference can be
+ in the index expressions. If they cannot be shown to be
+ identical, we have to say we don't know what the aliasing
+ relation will be. Now, since the IR is flattened, the index
+ expressions should be atoms -- either consts or tmps. So that
+ makes the comparison simple. */
+ vassert(isIRAtom(ix1));
+ vassert(isIRAtom(ix2));
+ if (!eqIRAtom(ix1,ix2))
+ return UnknownAlias;
+
+ /* Ok, the index expressions are identical. So now the only way
+ they can be different is in the bias. Normalise this
+ paranoidly, to reliably establish equality/non-equality. */
+
+ /* So now we know that the GetI and PutI index the same array
+ with the same base. Are the offsets the same, modulo the
+ array size? Do this paranoidly. */
+ vassert(descr1->nElems =3D=3D descr2->nElems);
+ vassert(descr1->elemTy =3D=3D descr2->elemTy);
+ vassert(descr1->base =3D=3D descr2->base);
+ iters =3D 0;
+ while (bias1 < 0 || bias2 < 0) {
+ bias1 +=3D descr1->nElems;
+ bias2 +=3D descr1->nElems;
+ iters++;
+ if (iters > 10)
+ vpanic("getAliasingRelation: iters");
+ }
+ vassert(bias1 >=3D 0 && bias2 >=3D 0);
+ bias1 %=3D descr1->nElems;
+ bias2 %=3D descr1->nElems;
+ vassert(bias1 >=3D 0 && bias1 < descr1->nElems);
+ vassert(bias2 >=3D 0 && bias2 < descr1->nElems);
+
+ /* Finally, biasP and biasG are normalised into the range=20
+ 0 .. descrP/G->nElems - 1. And so we can establish
+ equality/non-equality. */
+
+ return bias1=3D=3Dbias2 ? ExactAlias : NoAlias;
+}
+
+
+/*---------------------------------------------------------------*/
/*--- Common Subexpression Elimination ---*/
/*---------------------------------------------------------------*/
=20
@@ -2042,7 +2155,7 @@
=20
typedef
struct {
- enum { Ut, Btt, Btc, Bct, Cf64i } tag;
+ enum { Ut, Btt, Btc, Bct, Cf64i, Mttt, GetIt } tag;
union {
/* unop(tmp) */
struct {
@@ -2071,6 +2184,18 @@
struct {
ULong f64i;
} Cf64i;
+ /* Mux0X(tmp,tmp,tmp) */
+ struct {
+ IRTemp co;
+ IRTemp e0;
+ IRTemp eX;
+ } Mttt;
+ /* GetI(descr,tmp,bias)*/
+ struct {
+ IRArray* descr;
+ IRTemp ix;
+ Int bias;
+ } GetIt;
} u;
}
AvailExpr;
@@ -2101,6 +2226,14 @@
&& eqIRConst(&a1->u.Bct.con1, &a2->u.Bct.con1));
case Cf64i:=20
return toBool(a1->u.Cf64i.f64i =3D=3D a2->u.Cf64i.f64i);
+ case Mttt:
+ return toBool(a1->u.Mttt.co =3D=3D a2->u.Mttt.co
+ && a1->u.Mttt.e0 =3D=3D a2->u.Mttt.e0
+ && a1->u.Mttt.eX =3D=3D a2->u.Mttt.eX);
+ case GetIt:
+ return toBool(eqIRArray(a1->u.GetIt.descr, a2->u.GetIt.descr)=20
+ && a1->u.GetIt.ix =3D=3D a2->u.GetIt.ix
+ && a1->u.GetIt.bias =3D=3D a2->u.GetIt.bias);
default: vpanic("eq_AvailExpr");
}
}
@@ -2127,6 +2260,14 @@
IRExpr_Const(con), IRExpr_Tmp(ae->u.Bct.ar=
g2) );
case Cf64i:
return IRExpr_Const(IRConst_F64i(ae->u.Cf64i.f64i));
+ case Mttt:
+ return IRExpr_Mux0X(IRExpr_Tmp(ae->u.Mttt.co),=20
+ IRExpr_Tmp(ae->u.Mttt.e0),=20
+ IRExpr_Tmp(ae->u.Mttt.eX));
+ case GetIt:
+ return IRExpr_GetI(ae->u.GetIt.descr,
+ IRExpr_Tmp(ae->u.GetIt.ix),
+ ae->u.GetIt.bias);
default:
vpanic("availExpr_to_IRExpr");
}
@@ -2162,6 +2303,14 @@
break;
case Cf64i:
break;
+ case Mttt:
+ ae->u.Mttt.co =3D subst_AvailExpr_Temp( env, ae->u.Mttt.co );
+ ae->u.Mttt.e0 =3D subst_AvailExpr_Temp( env, ae->u.Mttt.e0 );
+ ae->u.Mttt.eX =3D subst_AvailExpr_Temp( env, ae->u.Mttt.eX );
+ break;
+ case GetIt:
+ ae->u.GetIt.ix =3D subst_AvailExpr_Temp( env, ae->u.GetIt.ix );
+ break;
default:=20
vpanic("subst_AvailExpr");
}
@@ -2221,18 +2370,44 @@
return ae;
}
=20
+ if (e->tag =3D=3D Iex_Mux0X
+ && e->Iex.Mux0X.cond->tag =3D=3D Iex_Tmp
+ && e->Iex.Mux0X.expr0->tag =3D=3D Iex_Tmp
+ && e->Iex.Mux0X.exprX->tag =3D=3D Iex_Tmp) {
+ ae =3D LibVEX_Alloc(sizeof(AvailExpr));
+ ae->tag =3D Mttt;
+ ae->u.Mttt.co =3D e->Iex.Mux0X.cond->Iex.Tmp.tmp;
+ ae->u.Mttt.e0 =3D e->Iex.Mux0X.expr0->Iex.Tmp.tmp;
+ ae->u.Mttt.eX =3D e->Iex.Mux0X.exprX->Iex.Tmp.tmp;
+ return ae;
+ }
+
+ if (e->tag =3D=3D Iex_GetI
+ && e->Iex.GetI.ix->tag =3D=3D Iex_Tmp) {
+ ae =3D LibVEX_Alloc(sizeof(AvailExpr));
+ ae->tag =3D GetIt;
+ ae->u.GetIt.descr =3D e->Iex.GetI.descr;
+ ae->u.GetIt.ix =3D e->Iex.GetI.ix->Iex.Tmp.tmp;
+ ae->u.GetIt.bias =3D e->Iex.GetI.bias;
+ return ae;
+ }
+
return NULL;
}
=20
=20
-/* The BB is modified in-place. */
+/* The BB is modified in-place. Returns True if any changes were
+ made. */
=20
-void do_cse_BB ( IRBB* bb )
+static Bool do_cse_BB ( IRBB* bb )
{
- Int i, j;
+ Int i, j, paranoia;
IRTemp t, q;
IRStmt* st;
AvailExpr* eprime;
+ AvailExpr* ae;
+ Bool invalidate;
+ Bool anyDone =3D False;
=20
HashHW* tenv =3D newHHW(); /* :: IRTemp -> IRTemp */
HashHW* aenv =3D newHHW(); /* :: AvailExpr* -> IRTemp */
@@ -2251,11 +2426,82 @@
else
add binding E' -> t to aenv
replace this stmt by "t =3D E'"
- Ignore any other kind of stmt.
+
+ Other statements are only interesting to the extent that they
+ might invalidate some of the expressions in aenv. So there is
+ an invalidate-bindings check for each statement seen.
*/
for (i =3D 0; i < bb->stmts_used; i++) {
st =3D bb->stmts[i];
=20
+ /* ------ BEGIN invalidate aenv bindings ------ */
+ /* This is critical: remove from aenv any E' -> .. bindings
+ which might be invalidated by this statement. The only
+ vulnerable kind of bindings are the GetIt kind.
+ Dirty call - dump (paranoia level -> 2)=20
+ Store - dump (ditto)=20
+ Put, PutI - dump unless no-overlap is proven (.. -> 1)
+ Uses getAliasingRelation_IC and getAliasingRelation_II
+ to do the no-overlap assessments needed for Put/PutI.
+ */
+ switch (st->tag) {
+ case Ist_Dirty: case Ist_Store:=20
+ paranoia =3D 2; break;
+ case Ist_Put: case Ist_PutI:=20
+ paranoia =3D 1; break;
+ case Ist_NoOp: case Ist_IMark: case Ist_AbiHint:=20
+ case Ist_Tmp: case Ist_MFence: case Ist_Exit:=20
+ paranoia =3D 0; break;
+ default:=20
+ vpanic("do_cse_BB(1)");
+ }
+
+ if (paranoia > 0) {
+ for (j =3D 0; j < aenv->used; j++) {
+ if (!aenv->inuse[j])
+ continue;
+ ae =3D (AvailExpr*)aenv->key[j];
+ if (ae->tag !=3D GetIt)=20
+ continue;
+ invalidate =3D False;
+ if (paranoia >=3D 2) {
+ invalidate =3D True;
+ } else {
+ vassert(paranoia =3D=3D 1);
+ if (st->tag =3D=3D Ist_Put) {
+ if (getAliasingRelation_IC(
+ ae->u.GetIt.descr,=20
+ IRExpr_Tmp(ae->u.GetIt.ix),=20
+ st->Ist.Put.offset,=20
+ typeOfIRExpr(bb->tyenv,st->Ist.Put.data)=20
+ ) !=3D NoAlias)=20
+ invalidate =3D True;
+ }
+ else=20
+ if (st->tag =3D=3D Ist_PutI) {
+ if (getAliasingRelation_II(
+ ae->u.GetIt.descr,=20
+ IRExpr_Tmp(ae->u.GetIt.ix),=20
+ ae->u.GetIt.bias,
+ st->Ist.PutI.descr,
+ st->Ist.PutI.ix,
+ st->Ist.PutI.bias
+ ) !=3D NoAlias)
+ invalidate =3D True;
+ }
+ else=20
+ vpanic("do_cse_BB(2)");
+ }
+
+ if (invalidate) {
+ aenv->inuse[j] =3D False;
+ aenv->key[j] =3D (HWord)NULL; /* be sure */
+ }
+ } /* for j */
+ } /* paranoia > 0 */
+
+ /* ------ ENV invalidate aenv bindings ------ */
+
/* ignore not-interestings */
if (st->tag !=3D Ist_Tmp)
continue;
@@ -2283,6 +2529,7 @@
q =3D (IRTemp)aenv->val[j];
bb->stmts[i] =3D IRStmt_Tmp( t, IRExpr_Tmp(q) );
addToHHW( tenv, (HWord)t, (HWord)q );
+ anyDone =3D True;
} else {
/* No binding was found, so instead we add E' -> t to our
collection of available expressions, replace this stmt
@@ -2297,6 +2544,7 @@
sanityCheckIRBB(bb, Ity_I32);
vex_printf("\n\n");
*/
+ return anyDone;
}
=20
=20
@@ -2479,115 +2727,6 @@
/*--- PutI/GetI transformations ---*/
/*---------------------------------------------------------------*/
=20
-/* ------- Helper functions for PutI/GetI transformations ------ */
-
-/* Determine, to the extent possible, the relationship between two
- guest state accesses. The possible outcomes are:
-
- * Exact alias. These two accesses denote precisely the same
- piece of the guest state.
-
- * Definitely no alias. These two accesses are guaranteed not to
- overlap any part of the guest state.
-
- * Unknown -- if neither of the above can be established.
-
- If in doubt, return Unknown. */
-
-typedef
- enum { ExactAlias, NoAlias, UnknownAlias }
- GSAliasing;
-
-
-/* Produces the alias relation between an indexed guest
- state access and a non-indexed access. */
-
-static
-GSAliasing getAliasingRelation_IC ( IRArray* descr1, IRExpr* ix1,
- Int offset2, IRType ty2 )
-{
- UInt minoff1, maxoff1, minoff2, maxoff2;
-
- getArrayBounds( descr1, &minoff1, &maxoff1 );
- minoff2 =3D offset2;
- maxoff2 =3D minoff2 + sizeofIRType(ty2) - 1;
-
- if (maxoff1 < minoff2 || maxoff2 < minoff1)
- return NoAlias;
-
- /* Could probably do better here if required. For the moment
- however just claim not to know anything more. */
- return UnknownAlias;
-}
-
-
-/* Produces the alias relation between two indexed guest state
- accesses. */
-
-static
-GSAliasing getAliasingRelation_II (=20
- IRArray* descr1, IRExpr* ix1, Int bias1,
- IRArray* descr2, IRExpr* ix2, Int bias2
- )
-{
- UInt minoff1, maxoff1, minoff2, maxoff2;
- Int iters;
-
- /* First try hard to show they don't alias. */
- getArrayBounds( descr1, &minoff1, &maxoff1 );
- getArrayBounds( descr2, &minoff2, &maxoff2 );
- if (maxoff1 < minoff2 || maxoff2 < minoff1)
- return NoAlias;
-
- /* So the two arrays at least partially overlap. To get any
- further we'll have to be sure that the descriptors are
- identical. */
- if (!eqIRArray(descr1, descr2))
- return UnknownAlias;
-
- /* The descriptors are identical. Now the only difference can be
- in the index expressions. If they cannot be shown to be
- identical, we have to say we don't know what the aliasing
- relation will be. Now, since the IR is flattened, the index
- expressions should be atoms -- either consts or tmps. So that
- makes the comparison simple. */
- vassert(isIRAtom(ix1));
- vassert(isIRAtom(ix2));
- if (!eqIRAtom(ix1,ix2))
- return UnknownAlias;
-
- /* Ok, the index expressions are identical. So now the only way
- they can be different is in the bias. Normalise this
- paranoidly, to reliably establish equality/non-equality. */
-
- /* So now we know that the GetI and PutI index the same array
- with the same base. Are the offsets the same, modulo the
- array size? Do this paranoidly. */
- vassert(descr1->nElems =3D=3D descr2->nElems);
- vassert(descr1->elemTy =3D=3D descr2->elemTy);
- vassert(descr1->base =3D=3D descr2->base);
- iters =3D 0;
- while (bias1 < 0 || bias2 < 0) {
- bias1 +=3D descr1->nElems;
- bias2 +=3D descr1->nElems;
- iters++;
- if (iters > 10)
- vpanic("getAliasingRelation: iters");
- }
- vassert(bias1 >=3D 0 && bias2 >=3D 0);
- bias1 %=3D descr1->nElems;
- bias2 %=3D descr1->nElems;
- vassert(bias1 >=3D 0 && bias1 < descr1->nElems);
- vassert(bias2 >=3D 0 && bias2 < descr1->nElems);
-
- /* Finally, biasP and biasG are normalised into the range=20
- 0 .. descrP/G->nElems - 1. And so we can establish
- equality/non-equality. */
-
- return bias1=3D=3Dbias2 ? ExactAlias : NoAlias;
-}
-
-
/* Given the parts (descr, tmp, bias) for a GetI, scan backwards from
the given starting point to find, if any, a PutI which writes
exactly the same piece of guest state, and so return the expression
@@ -3846,7 +3985,7 @@
static
IRBB* expensive_transformations( IRBB* bb )
{
- do_cse_BB( bb );
+ (void)do_cse_BB( bb );
collapse_AddSub_chains_BB( bb );
do_redundant_GetI_elimination( bb );
do_redundant_PutI_elimination( bb );
@@ -3977,20 +4116,27 @@
at it. */
considerExpensives( &hasGetIorPutI, &hasVorFtemps, bb );
=20
- if (hasVorFtemps) {
+ if (hasVorFtemps && !hasGetIorPutI) {
/* If any evidence of FP or Vector activity, CSE, as that
tends to mop up all manner of lardy code to do with
- rounding modes. */
- do_cse_BB( bb );
+ rounding modes. Don't bother if hasGetIorPutI since that
+ case leads into the expensive transformations, which do
+ CSE anyway. */
+ (void)do_cse_BB( bb );
do_deadcode_BB( bb );
}
=20
if (hasGetIorPutI) {
+ Bool cses;
n_expensive++;
if (DEBUG_IROPT)
vex_printf("***** EXPENSIVE %d %d\n", n_total, n_expensive);
bb =3D expensive_transformations( bb );
bb =3D cheap_transformations( bb, specHelper, preciseMemExnsFn =
);
+ /* Potentially common up GetIs */
+ cses =3D do_cse_BB( bb );
+ if (cses)
+ bb =3D cheap_transformations( bb, specHelper, preciseMemExns=
Fn );
}
=20
/* Now have a go at unrolling simple (single-BB) loops. If
Modified: trunk/priv/ir/iropt.h
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/priv/ir/iropt.h 2006-02-04 15:20:13 UTC (rev 1565)
+++ trunk/priv/ir/iropt.h 2006-02-04 15:24:00 UTC (rev 1566)
@@ -67,10 +67,6 @@
extern
void do_deadcode_BB ( IRBB* bb );
=20
-/* Do a CSE pass. bb is destructively modified. */
-extern
-void do_cse_BB ( IRBB* bb );
-
/* The tree-builder. Make (approximately) maximal safe trees. bb is
destructively modified. */
extern
|
|
From: <sv...@va...> - 2006-02-04 15:20:19
|
Author: sewardj
Date: 2006-02-04 15:20:13 +0000 (Sat, 04 Feb 2006)
New Revision: 1565
Log:
More x86 tidying up following rounding changes.
Modified:
trunk/priv/guest-x86/toIR.c
trunk/priv/host-x86/isel.c
Modified: trunk/priv/guest-x86/toIR.c
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/priv/guest-x86/toIR.c 2006-02-03 22:54:17 UTC (rev 1564)
+++ trunk/priv/guest-x86/toIR.c 2006-02-04 15:20:13 UTC (rev 1565)
@@ -3973,9 +3973,16 @@
to get the C3210 flag values. */
assign( a1, get_ST(0) );
assign( a2, get_ST(1) );
- put_ST_UNCHECKED(0, binop(Iop_PRem1F64,
- mkexpr(a1), mkexpr(a2)));
- put_C3210( binop(Iop_PRem1C3210F64, mkexpr(a1), mkexpr(a2=
)) );
+ put_ST_UNCHECKED(0,=20
+ triop(Iop_PRem1F64,
+ get_FAKE_roundingmode(), /* XXXROUNDINGFIXME */
+ mkexpr(a1),=20
+ mkexpr(a2)));
+ put_C3210(
+ triop(Iop_PRem1C3210F64,
+ get_FAKE_roundingmode(), /* XXXROUNDINGFIXME */
+ mkexpr(a1),=20
+ mkexpr(a2)) );
break;
}
=20
@@ -3992,9 +3999,16 @@
to get the C3210 flag values. */
assign( a1, get_ST(0) );
assign( a2, get_ST(1) );
- put_ST_UNCHECKED(0, binop(Iop_PRemF64,
- mkexpr(a1), mkexpr(a2)));
- put_C3210( binop(Iop_PRemC3210F64, mkexpr(a1), mkexpr(a2)=
) );
+ put_ST_UNCHECKED(0,=20
+ triop(Iop_PRemF64,
+ get_FAKE_roundingmode(), /* XXXROUNDINGFIXME */
+ mkexpr(a1),=20
+ mkexpr(a2)));
+ put_C3210(=20
+ triop(Iop_PRemC3210F64,
+ get_FAKE_roundingmode(), /* XXXROUNDINGFIXME */
+ mkexpr(a1),=20
+ mkexpr(a2)) );
break;
}
=20
Modified: trunk/priv/host-x86/isel.c
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/priv/host-x86/isel.c 2006-02-03 22:54:17 UTC (rev 1564)
+++ trunk/priv/host-x86/isel.c 2006-02-04 15:20:13 UTC (rev 1565)
@@ -760,6 +760,34 @@
break;
}
=20
+ /* --------- TERNARY OP --------- */
+ case Iex_Triop: {
+ /* C3210 flags following FPU partial remainder (fprem), both
+ IEEE compliant (PREM1) and non-IEEE compliant (PREM). */
+ if (e->Iex.Triop.op =3D=3D Iop_PRemC3210F64
+ || e->Iex.Triop.op =3D=3D Iop_PRem1C3210F64) {
+ HReg junk =3D newVRegF(env);
+ HReg dst =3D newVRegI(env);
+ HReg srcL =3D iselDblExpr(env, e->Iex.Triop.arg2);
+ HReg srcR =3D iselDblExpr(env, e->Iex.Triop.arg3);
+ /* XXXROUNDINGFIXME */
+ /* set roundingmode here */
+ addInstr(env, X86Instr_FpBinary(
+ e->Iex.Binop.op=3D=3DIop_PRemC3210F64=20
+ ? Xfp_PREM : Xfp_PREM1,
+ srcL,srcR,junk
+ ));
+ /* The previous pseudo-insn will have left the FPU's C3210
+ flags set correctly. So bag them. */
+ addInstr(env, X86Instr_FpStSW_AX());
+ addInstr(env, mk_iMOVsd_RR(hregX86_EAX(), dst));
+ addInstr(env, X86Instr_Alu32R(Xalu_AND, X86RMI_Imm(0x4700), dst=
));
+ return dst;
+ }
+
+ break;
+ }
+
/* --------- BINARY OP --------- */
case Iex_Binop: {
X86AluOp aluOp;
@@ -972,27 +1000,6 @@
return dst;
}
=20
- /* C3210 flags following FPU partial remainder (fprem), both
- IEEE compliant (PREM1) and non-IEEE compliant (PREM). */
- if (e->Iex.Binop.op =3D=3D Iop_PRemC3210F64
- || e->Iex.Binop.op =3D=3D Iop_PRem1C3210F64) {
- HReg junk =3D newVRegF(env);
- HReg dst =3D newVRegI(env);
- HReg srcL =3D iselDblExpr(env, e->Iex.Binop.arg1);
- HReg srcR =3D iselDblExpr(env, e->Iex.Binop.arg2);
- addInstr(env, X86Instr_FpBinary(
- e->Iex.Binop.op=3D=3DIop_PRemC3210F64=20
- ? Xfp_PREM : Xfp_PREM1,
- srcL,srcR,junk
- ));
- /* The previous pseudo-insn will have left the FPU's C3210
- flags set correctly. So bag them. */
- addInstr(env, X86Instr_FpStSW_AX());
- addInstr(env, mk_iMOVsd_RR(hregX86_EAX(), dst));
- addInstr(env, X86Instr_Alu32R(Xalu_AND, X86RMI_Imm(0x4700), dst));
- return dst;
- }
-
break;
}
=20
@@ -2615,6 +2622,8 @@
case Iop_Yl2xF64: fpop =3D Xfp_YL2X; break;
case Iop_Yl2xp1F64: fpop =3D Xfp_YL2XP1; break;
case Iop_AtanF64: fpop =3D Xfp_ATAN; break;
+ case Iop_PRemF64: fpop =3D Xfp_PREM; break;
+ case Iop_PRem1F64: fpop =3D Xfp_PREM1; break;
default: break;
}
if (fpop !=3D Xfp_INVALID) {
@@ -2631,25 +2640,6 @@
}
}
=20
- if (e->tag =3D=3D Iex_Binop) {
- X86FpOp fpop =3D Xfp_INVALID;
- switch (e->Iex.Binop.op) {
- case Iop_PRemF64: fpop =3D Xfp_PREM; break;
- case Iop_PRem1F64: fpop =3D Xfp_PREM1; break;
- default: break;
- }
- if (fpop !=3D Xfp_INVALID) {
- HReg res =3D newVRegF(env);
- HReg srcL =3D iselDblExpr(env, e->Iex.Binop.arg1);
- HReg srcR =3D iselDblExpr(env, e->Iex.Binop.arg2);
- addInstr(env, X86Instr_FpBinary(fpop,srcL,srcR,res));
- if (fpop !=3D Xfp_ADD && fpop !=3D Xfp_SUB=20
- && fpop !=3D Xfp_MUL && fpop !=3D Xfp_DIV)
- roundToF64(env, res);
- return res;
- }
- }
-
if (e->tag =3D=3D Iex_Binop && e->Iex.Binop.op =3D=3D Iop_RoundF64toI=
nt) {
HReg rf =3D iselDblExpr(env, e->Iex.Binop.arg2);
HReg dst =3D newVRegF(env);
|
|
From: <js...@ac...> - 2006-02-04 11:26:07
|
Nightly build on minnie ( SuSE 10.0, ppc32 ) started at 2006-02-04 05:00:02 GMT
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 190 tests, 11 stderr failures, 5 stdout failures =================
memcheck/tests/leak-cycle (stderr)
memcheck/tests/leak-tree (stderr)
memcheck/tests/leakotron (stdout)
memcheck/tests/mempool (stderr)
memcheck/tests/pointer-trace (stderr)
memcheck/tests/sigaltstack (stderr)
memcheck/tests/stack_changes (stdout)
memcheck/tests/stack_changes (stderr)
memcheck/tests/xml1 (stderr)
none/tests/faultstatus (stderr)
none/tests/mremap (stderr)
none/tests/ppc32/jm-fp (stdout)
none/tests/ppc32/jm-fp (stderr)
none/tests/ppc32/test_fx (stdout)
none/tests/ppc32/test_fx (stderr)
none/tests/ppc32/test_gx (stdout)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
then mv -f ".deps/memcheck_ppc32_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_ppc32_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_ppc32_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_ppc32_linux-mc_main.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mc_main.Tpo" -c -o memcheck_ppc32_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
then mv -f ".deps/memcheck_ppc32_linux-mc_main.Tpo" ".deps/memcheck_ppc32_linux-mc_main.Po"; else rm -f ".deps/memcheck_ppc32_linux-mc_main.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_ppc32_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mac_shared.Tpo" -c -o memcheck_ppc32_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
then mv -f ".deps/memcheck_ppc32_linux-mac_shared.Tpo" ".deps/memcheck_ppc32_linux-mac_shared.Po"; else rm -f ".deps/memcheck_ppc32_linux-mac_shared.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_ppc32_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mc_translate.Tpo" -c -o memcheck_ppc32_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
then mv -f ".deps/memcheck_ppc32_linux-mc_translate.Tpo" ".deps/memcheck_ppc32_linux-mc_translate.Po"; else rm -f ".deps/memcheck_ppc32_linux-mc_translate.Tpo"; exit 1; fi
mc_translate.c: In function 'expr2vbits_Binop':
mc_translate.c:1909: error: 'Iop_RoundF64' undeclared (first use in this function)
mc_translate.c:1909: error: (Each undeclared identifier is reported only once
mc_translate.c:1909: error: for each function it appears in.)
mc_translate.c: In function 'expr2vbits_Unop':
mc_translate.c:2188: error: 'Iop_Est8FRecip' undeclared (first use in this function)
make[3]: *** [memcheck_ppc32_linux-mc_translate.o] Error 1
make[3]: Leaving directory `/home/sewardj/Nightly/valgrind/memcheck'
make[2]: *** [all-recursive] Error 1
make[2]: Leaving directory `/home/sewardj/Nightly/valgrind/memcheck'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/home/sewardj/Nightly/valgrind'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Sat Feb 4 05:03:18 2006
--- new.short Sat Feb 4 05:13:24 2006
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- then mv -f ".deps/memcheck_ppc32_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_ppc32_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_ppc32_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_ppc32_linux-mc_main.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mc_main.Tpo" -c -o memcheck_ppc32_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
- then mv -f ".deps/memcheck_ppc32_linux-mc_main.Tpo" ".deps/memcheck_ppc32_linux-mc_main.Po"; else rm -f ".deps/memcheck_ppc32_linux-mc_main.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_ppc32_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mac_shared.Tpo" -c -o memcheck_ppc32_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
- then mv -f ".deps/memcheck_ppc32_linux-mac_shared.Tpo" ".deps/memcheck_ppc32_linux-mac_shared.Po"; else rm -f ".deps/memcheck_ppc32_linux-mac_shared.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_ppc32_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mc_translate.Tpo" -c -o memcheck_ppc32_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
- then mv -f ".deps/memcheck_ppc32_linux-mc_translate.Tpo" ".deps/memcheck_ppc32_linux-mc_translate.Po"; else rm -f ".deps/memcheck_ppc32_linux-mc_translate.Tpo"; exit 1; fi
- mc_translate.c: In function 'expr2vbits_Binop':
- mc_translate.c:1909: error: 'Iop_RoundF64' undeclared (first use in this function)
- mc_translate.c:1909: error: (Each undeclared identifier is reported only once
- mc_translate.c:1909: error: for each function it appears in.)
- mc_translate.c: In function 'expr2vbits_Unop':
- mc_translate.c:2188: error: 'Iop_Est8FRecip' undeclared (first use in this function)
- make[3]: *** [memcheck_ppc32_linux-mc_translate.o] Error 1
- make[3]: Leaving directory `/home/sewardj/Nightly/valgrind/memcheck'
- make[2]: *** [all-recursive] Error 1
- make[2]: Leaving directory `/home/sewardj/Nightly/valgrind/memcheck'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/home/sewardj/Nightly/valgrind'
- make: *** [all] Error 2
--- 3,26 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 190 tests, 11 stderr failures, 5 stdout failures =================
! memcheck/tests/leak-cycle (stderr)
! memcheck/tests/leak-tree (stderr)
! memcheck/tests/leakotron (stdout)
! memcheck/tests/mempool (stderr)
! memcheck/tests/pointer-trace (stderr)
! memcheck/tests/sigaltstack (stderr)
! memcheck/tests/stack_changes (stdout)
! memcheck/tests/stack_changes (stderr)
! memcheck/tests/xml1 (stderr)
! none/tests/faultstatus (stderr)
! none/tests/mremap (stderr)
! none/tests/ppc32/jm-fp (stdout)
! none/tests/ppc32/jm-fp (stderr)
! none/tests/ppc32/test_fx (stdout)
! none/tests/ppc32/test_fx (stderr)
! none/tests/ppc32/test_gx (stdout)
|
|
From: <js...@ac...> - 2006-02-04 03:57:01
|
Nightly build on phoenix ( SuSE 10.0 ) started at 2006-02-04 03:30:01 GMT Checking out vex source tree ... done Building vex ... done Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 221 tests, 7 stderr failures, 0 stdout failures ================= memcheck/tests/leak-tree (stderr) memcheck/tests/pointer-trace (stderr) memcheck/tests/stack_switch (stderr) memcheck/tests/x86/scalar (stderr) memcheck/tests/x86/scalar_supp (stderr) none/tests/x86/faultstatus (stderr) none/tests/x86/int (stderr) |
|
From: <js...@ac...> - 2006-02-04 03:50:34
|
Nightly build on g5 ( YDL 4.0, ppc970 ) started at 2006-02-04 04:40:00 CET
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 194 tests, 6 stderr failures, 1 stdout failure =================
memcheck/tests/leak-cycle (stderr)
memcheck/tests/leak-tree (stderr)
memcheck/tests/leakotron (stdout)
memcheck/tests/pointer-trace (stderr)
none/tests/faultstatus (stderr)
none/tests/fdleak_fcntl (stderr)
none/tests/mremap (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
mac_malloc_wrappers.c:214: warning: called from here
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -MT memcheck_ppc32_linux-mc_main.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mc_main.Tpo" -c -o memcheck_ppc32_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
then mv -f ".deps/memcheck_ppc32_linux-mc_main.Tpo" ".deps/memcheck_ppc32_linux-mc_main.Po"; else rm -f ".deps/memcheck_ppc32_linux-mc_main.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -MT memcheck_ppc32_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mac_shared.Tpo" -c -o memcheck_ppc32_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
then mv -f ".deps/memcheck_ppc32_linux-mac_shared.Tpo" ".deps/memcheck_ppc32_linux-mac_shared.Po"; else rm -f ".deps/memcheck_ppc32_linux-mac_shared.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -MT memcheck_ppc32_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mc_translate.Tpo" -c -o memcheck_ppc32_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
then mv -f ".deps/memcheck_ppc32_linux-mc_translate.Tpo" ".deps/memcheck_ppc32_linux-mc_translate.Po"; else rm -f ".deps/memcheck_ppc32_linux-mc_translate.Tpo"; exit 1; fi
mc_translate.c: In function `expr2vbits_Binop':
mc_translate.c:1909: error: `Iop_RoundF64' undeclared (first use in this function)
mc_translate.c:1909: error: (Each undeclared identifier is reported only once
mc_translate.c:1909: error: for each function it appears in.)
mc_translate.c: In function `expr2vbits_Unop':
mc_translate.c:2188: error: `Iop_Est8FRecip' undeclared (first use in this function)
make[3]: *** [memcheck_ppc32_linux-mc_translate.o] Error 1
make[3]: Leaving directory `/home/sewardj/Nightly/valgrind/memcheck'
make[2]: *** [all-recursive] Error 1
make[2]: Leaving directory `/home/sewardj/Nightly/valgrind/memcheck'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/home/sewardj/Nightly/valgrind'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Sat Feb 4 04:42:04 2006
--- new.short Sat Feb 4 04:50:28 2006
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- mac_malloc_wrappers.c:214: warning: called from here
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -MT memcheck_ppc32_linux-mc_main.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mc_main.Tpo" -c -o memcheck_ppc32_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
- then mv -f ".deps/memcheck_ppc32_linux-mc_main.Tpo" ".deps/memcheck_ppc32_linux-mc_main.Po"; else rm -f ".deps/memcheck_ppc32_linux-mc_main.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -MT memcheck_ppc32_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mac_shared.Tpo" -c -o memcheck_ppc32_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
- then mv -f ".deps/memcheck_ppc32_linux-mac_shared.Tpo" ".deps/memcheck_ppc32_linux-mac_shared.Po"; else rm -f ".deps/memcheck_ppc32_linux-mac_shared.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_ppc32=1 -DVGO_linux=1 -DVGP_ppc32_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -MT memcheck_ppc32_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_ppc32_linux-mc_translate.Tpo" -c -o memcheck_ppc32_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
- then mv -f ".deps/memcheck_ppc32_linux-mc_translate.Tpo" ".deps/memcheck_ppc32_linux-mc_translate.Po"; else rm -f ".deps/memcheck_ppc32_linux-mc_translate.Tpo"; exit 1; fi
- mc_translate.c: In function `expr2vbits_Binop':
- mc_translate.c:1909: error: `Iop_RoundF64' undeclared (first use in this function)
- mc_translate.c:1909: error: (Each undeclared identifier is reported only once
- mc_translate.c:1909: error: for each function it appears in.)
- mc_translate.c: In function `expr2vbits_Unop':
- mc_translate.c:2188: error: `Iop_Est8FRecip' undeclared (first use in this function)
- make[3]: *** [memcheck_ppc32_linux-mc_translate.o] Error 1
- make[3]: Leaving directory `/home/sewardj/Nightly/valgrind/memcheck'
- make[2]: *** [all-recursive] Error 1
- make[2]: Leaving directory `/home/sewardj/Nightly/valgrind/memcheck'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/home/sewardj/Nightly/valgrind'
- make: *** [all] Error 2
--- 3,17 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 194 tests, 6 stderr failures, 1 stdout failure =================
! memcheck/tests/leak-cycle (stderr)
! memcheck/tests/leak-tree (stderr)
! memcheck/tests/leakotron (stdout)
! memcheck/tests/pointer-trace (stderr)
! none/tests/faultstatus (stderr)
! none/tests/fdleak_fcntl (stderr)
! none/tests/mremap (stderr)
|
|
From: Tom H. <to...@co...> - 2006-02-04 03:38:52
|
Nightly build on dunsmere ( athlon, Fedora Core 4 ) started at 2006-02-04 03:30:05 GMT
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 223 tests, 8 stderr failures, 1 stdout failure =================
memcheck/tests/leak-tree (stderr)
memcheck/tests/mempool (stderr)
memcheck/tests/pointer-trace (stderr)
memcheck/tests/stack_switch (stderr)
memcheck/tests/x86/scalar (stderr)
memcheck/tests/x86/scalar_supp (stderr)
memcheck/tests/x86/sse1_memory (stdout)
none/tests/x86/faultstatus (stderr)
none/tests/x86/int (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
then mv -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_x86_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_main.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_main.Tpo" -c -o memcheck_x86_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
then mv -f ".deps/memcheck_x86_linux-mc_main.Tpo" ".deps/memcheck_x86_linux-mc_main.Po"; else rm -f ".deps/memcheck_x86_linux-mc_main.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_x86_linux-mac_shared.Tpo" -c -o memcheck_x86_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
then mv -f ".deps/memcheck_x86_linux-mac_shared.Tpo" ".deps/memcheck_x86_linux-mac_shared.Po"; else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; fi
mc_translate.c: In function 'expr2vbits_Binop':
mc_translate.c:1909: error: 'Iop_RoundF64' undeclared (first use in this function)
mc_translate.c:1909: error: (Each undeclared identifier is reported only once
mc_translate.c:1909: error: for each function it appears in.)
mc_translate.c: In function 'expr2vbits_Unop':
mc_translate.c:2188: error: 'Iop_Est8FRecip' undeclared (first use in this function)
make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
make[3]: Leaving directory `/tmp/valgrind.3267/valgrind/memcheck'
make[2]: *** [all-recursive] Error 1
make[2]: Leaving directory `/tmp/valgrind.3267/valgrind/memcheck'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/tmp/valgrind.3267/valgrind'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Sat Feb 4 03:31:57 2006
--- new.short Sat Feb 4 03:38:46 2006
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- then mv -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_x86_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_main.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_main.Tpo" -c -o memcheck_x86_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_main.Tpo" ".deps/memcheck_x86_linux-mc_main.Po"; else rm -f ".deps/memcheck_x86_linux-mc_main.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_x86_linux-mac_shared.Tpo" -c -o memcheck_x86_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
- then mv -f ".deps/memcheck_x86_linux-mac_shared.Tpo" ".deps/memcheck_x86_linux-mac_shared.Po"; else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; fi
- mc_translate.c: In function 'expr2vbits_Binop':
- mc_translate.c:1909: error: 'Iop_RoundF64' undeclared (first use in this function)
- mc_translate.c:1909: error: (Each undeclared identifier is reported only once
- mc_translate.c:1909: error: for each function it appears in.)
- mc_translate.c: In function 'expr2vbits_Unop':
- mc_translate.c:2188: error: 'Iop_Est8FRecip' undeclared (first use in this function)
- make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
- make[3]: Leaving directory `/tmp/valgrind.3267/valgrind/memcheck'
- make[2]: *** [all-recursive] Error 1
- make[2]: Leaving directory `/tmp/valgrind.3267/valgrind/memcheck'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/tmp/valgrind.3267/valgrind'
- make: *** [all] Error 2
--- 3,19 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 223 tests, 8 stderr failures, 1 stdout failure =================
! memcheck/tests/leak-tree (stderr)
! memcheck/tests/mempool (stderr)
! memcheck/tests/pointer-trace (stderr)
! memcheck/tests/stack_switch (stderr)
! memcheck/tests/x86/scalar (stderr)
! memcheck/tests/x86/scalar_supp (stderr)
! memcheck/tests/x86/sse1_memory (stdout)
! none/tests/x86/faultstatus (stderr)
! none/tests/x86/int (stderr)
|
|
From: Tom H. <th...@cy...> - 2006-02-04 03:25:37
|
Nightly build on alvis ( i686, Red Hat 7.3 ) started at 2006-02-04 03:15:02 GMT
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 222 tests, 21 stderr failures, 1 stdout failure =================
memcheck/tests/addressable (stderr)
memcheck/tests/badjump (stderr)
memcheck/tests/describe-block (stderr)
memcheck/tests/erringfds (stderr)
memcheck/tests/leak-0 (stderr)
memcheck/tests/leak-cycle (stderr)
memcheck/tests/leak-regroot (stderr)
memcheck/tests/leak-tree (stderr)
memcheck/tests/match-overrun (stderr)
memcheck/tests/mempool (stderr)
memcheck/tests/partial_load_dflt (stderr)
memcheck/tests/partial_load_ok (stderr)
memcheck/tests/partiallydefinedeq (stderr)
memcheck/tests/pointer-trace (stderr)
memcheck/tests/sigkill (stderr)
memcheck/tests/stack_changes (stderr)
memcheck/tests/x86/scalar (stderr)
memcheck/tests/x86/scalar_supp (stderr)
memcheck/tests/x86/sse1_memory (stdout)
memcheck/tests/xml1 (stderr)
none/tests/x86/faultstatus (stderr)
none/tests/x86/int (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; \
fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" \
-c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; \
else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; \
fi
mc_translate.c: In function `expr2vbits_Binop':
mc_translate.c:1909: `Iop_RoundF64' undeclared (first use in this function)
mc_translate.c:1909: (Each undeclared identifier is reported only once
mc_translate.c:1909: for each function it appears in.)
mc_translate.c: In function `expr2vbits_Unop':
mc_translate.c:2188: `Iop_Est8FRecip' undeclared (first use in this function)
make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
make[3]: Leaving directory `/tmp/valgrind.2074/valgrind/memcheck'
make[2]: *** [all-recursive] Error 1
make[2]: Leaving directory `/tmp/valgrind.2074/valgrind/memcheck'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/tmp/valgrind.2074/valgrind'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Sat Feb 4 03:17:41 2006
--- new.short Sat Feb 4 03:25:32 2006
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; \
- fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" \
- -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; \
- else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; \
- fi
- mc_translate.c: In function `expr2vbits_Binop':
- mc_translate.c:1909: `Iop_RoundF64' undeclared (first use in this function)
- mc_translate.c:1909: (Each undeclared identifier is reported only once
- mc_translate.c:1909: for each function it appears in.)
- mc_translate.c: In function `expr2vbits_Unop':
- mc_translate.c:2188: `Iop_Est8FRecip' undeclared (first use in this function)
- make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
- make[3]: Leaving directory `/tmp/valgrind.2074/valgrind/memcheck'
- make[2]: *** [all-recursive] Error 1
- make[2]: Leaving directory `/tmp/valgrind.2074/valgrind/memcheck'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/tmp/valgrind.2074/valgrind'
- make: *** [all] Error 2
--- 3,32 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 222 tests, 21 stderr failures, 1 stdout failure =================
! memcheck/tests/addressable (stderr)
! memcheck/tests/badjump (stderr)
! memcheck/tests/describe-block (stderr)
! memcheck/tests/erringfds (stderr)
! memcheck/tests/leak-0 (stderr)
! memcheck/tests/leak-cycle (stderr)
! memcheck/tests/leak-regroot (stderr)
! memcheck/tests/leak-tree (stderr)
! memcheck/tests/match-overrun (stderr)
! memcheck/tests/mempool (stderr)
! memcheck/tests/partial_load_dflt (stderr)
! memcheck/tests/partial_load_ok (stderr)
! memcheck/tests/partiallydefinedeq (stderr)
! memcheck/tests/pointer-trace (stderr)
! memcheck/tests/sigkill (stderr)
! memcheck/tests/stack_changes (stderr)
! memcheck/tests/x86/scalar (stderr)
! memcheck/tests/x86/scalar_supp (stderr)
! memcheck/tests/x86/sse1_memory (stdout)
! memcheck/tests/xml1 (stderr)
! none/tests/x86/faultstatus (stderr)
! none/tests/x86/int (stderr)
|
|
From: Tom H. <th...@cy...> - 2006-02-04 03:19:31
|
Nightly build on dellow ( x86_64, Fedora Core 4 ) started at 2006-02-04 03:10:10 GMT
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 242 tests, 8 stderr failures, 3 stdout failures =================
memcheck/tests/amd64/insn_fpu (stdout)
memcheck/tests/amd64/insn_fpu (stderr)
memcheck/tests/pointer-trace (stderr)
memcheck/tests/x86/scalar (stderr)
memcheck/tests/x86/scalar_supp (stderr)
memcheck/tests/x86/sse1_memory (stdout)
none/tests/amd64/faultstatus (stderr)
none/tests/amd64/insn_fpu (stdout)
none/tests/amd64/insn_fpu (stderr)
none/tests/x86/faultstatus (stderr)
none/tests/x86/int (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
then mv -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_x86_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_main.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_main.Tpo" -c -o memcheck_x86_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
then mv -f ".deps/memcheck_x86_linux-mc_main.Tpo" ".deps/memcheck_x86_linux-mc_main.Po"; else rm -f ".deps/memcheck_x86_linux-mc_main.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_x86_linux-mac_shared.Tpo" -c -o memcheck_x86_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
then mv -f ".deps/memcheck_x86_linux-mac_shared.Tpo" ".deps/memcheck_x86_linux-mac_shared.Po"; else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; fi
mc_translate.c: In function 'expr2vbits_Binop':
mc_translate.c:1909: error: 'Iop_RoundF64' undeclared (first use in this function)
mc_translate.c:1909: error: (Each undeclared identifier is reported only once
mc_translate.c:1909: error: for each function it appears in.)
mc_translate.c: In function 'expr2vbits_Unop':
mc_translate.c:2188: error: 'Iop_Est8FRecip' undeclared (first use in this function)
make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
make[3]: Leaving directory `/tmp/valgrind.27597/valgrind/memcheck'
make[2]: *** [all-recursive] Error 1
make[2]: Leaving directory `/tmp/valgrind.27597/valgrind/memcheck'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/tmp/valgrind.27597/valgrind'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Sat Feb 4 03:12:45 2006
--- new.short Sat Feb 4 03:19:25 2006
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- then mv -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_x86_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_main.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_main.Tpo" -c -o memcheck_x86_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_main.Tpo" ".deps/memcheck_x86_linux-mc_main.Po"; else rm -f ".deps/memcheck_x86_linux-mc_main.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_x86_linux-mac_shared.Tpo" -c -o memcheck_x86_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
- then mv -f ".deps/memcheck_x86_linux-mac_shared.Tpo" ".deps/memcheck_x86_linux-mac_shared.Po"; else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wno-pointer-sign -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; fi
- mc_translate.c: In function 'expr2vbits_Binop':
- mc_translate.c:1909: error: 'Iop_RoundF64' undeclared (first use in this function)
- mc_translate.c:1909: error: (Each undeclared identifier is reported only once
- mc_translate.c:1909: error: for each function it appears in.)
- mc_translate.c: In function 'expr2vbits_Unop':
- mc_translate.c:2188: error: 'Iop_Est8FRecip' undeclared (first use in this function)
- make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
- make[3]: Leaving directory `/tmp/valgrind.27597/valgrind/memcheck'
- make[2]: *** [all-recursive] Error 1
- make[2]: Leaving directory `/tmp/valgrind.27597/valgrind/memcheck'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/tmp/valgrind.27597/valgrind'
- make: *** [all] Error 2
--- 3,21 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 242 tests, 8 stderr failures, 3 stdout failures =================
! memcheck/tests/amd64/insn_fpu (stdout)
! memcheck/tests/amd64/insn_fpu (stderr)
! memcheck/tests/pointer-trace (stderr)
! memcheck/tests/x86/scalar (stderr)
! memcheck/tests/x86/scalar_supp (stderr)
! memcheck/tests/x86/sse1_memory (stdout)
! none/tests/amd64/faultstatus (stderr)
! none/tests/amd64/insn_fpu (stdout)
! none/tests/amd64/insn_fpu (stderr)
! none/tests/x86/faultstatus (stderr)
! none/tests/x86/int (stderr)
|
|
From: Tom H. <th...@cy...> - 2006-02-04 03:16:45
|
Nightly build on aston ( x86_64, Fedora Core 3 ) started at 2006-02-04 03:05:07 GMT
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 242 tests, 8 stderr failures, 3 stdout failures =================
memcheck/tests/amd64/insn_fpu (stdout)
memcheck/tests/amd64/insn_fpu (stderr)
memcheck/tests/stack_switch (stderr)
memcheck/tests/x86/scalar (stderr)
memcheck/tests/x86/scalar_supp (stderr)
memcheck/tests/x86/sse1_memory (stdout)
none/tests/amd64/faultstatus (stderr)
none/tests/amd64/insn_fpu (stdout)
none/tests/amd64/insn_fpu (stderr)
none/tests/x86/faultstatus (stderr)
none/tests/x86/int (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
then mv -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_x86_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_main.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_main.Tpo" -c -o memcheck_x86_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
then mv -f ".deps/memcheck_x86_linux-mc_main.Tpo" ".deps/memcheck_x86_linux-mc_main.Po"; else rm -f ".deps/memcheck_x86_linux-mc_main.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_x86_linux-mac_shared.Tpo" -c -o memcheck_x86_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
then mv -f ".deps/memcheck_x86_linux-mac_shared.Tpo" ".deps/memcheck_x86_linux-mac_shared.Po"; else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; fi
mc_translate.c: In function `expr2vbits_Binop':
mc_translate.c:1909: error: `Iop_RoundF64' undeclared (first use in this function)
mc_translate.c:1909: error: (Each undeclared identifier is reported only once
mc_translate.c:1909: error: for each function it appears in.)
mc_translate.c: In function `expr2vbits_Unop':
mc_translate.c:2188: error: `Iop_Est8FRecip' undeclared (first use in this function)
make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
make[3]: Leaving directory `/tmp/valgrind.27473/valgrind/memcheck'
make[2]: *** [all-recursive] Error 1
make[2]: Leaving directory `/tmp/valgrind.27473/valgrind/memcheck'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/tmp/valgrind.27473/valgrind'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Sat Feb 4 03:09:00 2006
--- new.short Sat Feb 4 03:16:39 2006
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- then mv -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_x86_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_main.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_main.Tpo" -c -o memcheck_x86_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_main.Tpo" ".deps/memcheck_x86_linux-mc_main.Po"; else rm -f ".deps/memcheck_x86_linux-mc_main.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_x86_linux-mac_shared.Tpo" -c -o memcheck_x86_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
- then mv -f ".deps/memcheck_x86_linux-mac_shared.Tpo" ".deps/memcheck_x86_linux-mac_shared.Po"; else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; fi
- mc_translate.c: In function `expr2vbits_Binop':
- mc_translate.c:1909: error: `Iop_RoundF64' undeclared (first use in this function)
- mc_translate.c:1909: error: (Each undeclared identifier is reported only once
- mc_translate.c:1909: error: for each function it appears in.)
- mc_translate.c: In function `expr2vbits_Unop':
- mc_translate.c:2188: error: `Iop_Est8FRecip' undeclared (first use in this function)
- make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
- make[3]: Leaving directory `/tmp/valgrind.27473/valgrind/memcheck'
- make[2]: *** [all-recursive] Error 1
- make[2]: Leaving directory `/tmp/valgrind.27473/valgrind/memcheck'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/tmp/valgrind.27473/valgrind'
- make: *** [all] Error 2
--- 3,21 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 242 tests, 8 stderr failures, 3 stdout failures =================
! memcheck/tests/amd64/insn_fpu (stdout)
! memcheck/tests/amd64/insn_fpu (stderr)
! memcheck/tests/stack_switch (stderr)
! memcheck/tests/x86/scalar (stderr)
! memcheck/tests/x86/scalar_supp (stderr)
! memcheck/tests/x86/sse1_memory (stdout)
! none/tests/amd64/faultstatus (stderr)
! none/tests/amd64/insn_fpu (stdout)
! none/tests/amd64/insn_fpu (stderr)
! none/tests/x86/faultstatus (stderr)
! none/tests/x86/int (stderr)
|
|
From: Tom H. <th...@cy...> - 2006-02-04 03:11:46
|
Nightly build on gill ( x86_64, Fedora Core 2 ) started at 2006-02-04 03:00:03 GMT
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 242 tests, 9 stderr failures, 3 stdout failures =================
memcheck/tests/amd64/insn_fpu (stdout)
memcheck/tests/amd64/insn_fpu (stderr)
memcheck/tests/stack_switch (stderr)
memcheck/tests/x86/scalar (stderr)
memcheck/tests/x86/scalar_supp (stderr)
memcheck/tests/x86/sse1_memory (stdout)
none/tests/amd64/faultstatus (stderr)
none/tests/amd64/insn_fpu (stdout)
none/tests/amd64/insn_fpu (stderr)
none/tests/fdleak_fcntl (stderr)
none/tests/x86/faultstatus (stderr)
none/tests/x86/int (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
then mv -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_x86_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_main.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_main.Tpo" -c -o memcheck_x86_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
then mv -f ".deps/memcheck_x86_linux-mc_main.Tpo" ".deps/memcheck_x86_linux-mc_main.Po"; else rm -f ".deps/memcheck_x86_linux-mc_main.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_x86_linux-mac_shared.Tpo" -c -o memcheck_x86_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
then mv -f ".deps/memcheck_x86_linux-mac_shared.Tpo" ".deps/memcheck_x86_linux-mac_shared.Po"; else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; fi
if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; fi
mc_translate.c: In function `expr2vbits_Binop':
mc_translate.c:1909: error: `Iop_RoundF64' undeclared (first use in this function)
mc_translate.c:1909: error: (Each undeclared identifier is reported only once
mc_translate.c:1909: error: for each function it appears in.)
mc_translate.c: In function `expr2vbits_Unop':
mc_translate.c:2188: error: `Iop_Est8FRecip' undeclared (first use in this function)
make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
make[3]: Leaving directory `/tmp/valgrind.13609/valgrind/memcheck'
make[2]: *** [all-recursive] Error 1
make[2]: Leaving directory `/tmp/valgrind.13609/valgrind/memcheck'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/tmp/valgrind.13609/valgrind'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Sat Feb 4 03:02:12 2006
--- new.short Sat Feb 4 03:11:37 2006
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- then mv -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo" ".deps/memcheck_x86_linux-mac_malloc_wrappers.Po"; else rm -f ".deps/memcheck_x86_linux-mac_malloc_wrappers.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_main.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_main.Tpo" -c -o memcheck_x86_linux-mc_main.o `test -f 'mc_main.c' || echo './'`mc_main.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_main.Tpo" ".deps/memcheck_x86_linux-mc_main.Po"; else rm -f ".deps/memcheck_x86_linux-mc_main.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mac_shared.o -MD -MP -MF ".deps/memcheck_x86_linux-mac_shared.Tpo" -c -o memcheck_x86_linux-mac_shared.o `test -f 'mac_shared.c' || echo './'`mac_shared.c; \
- then mv -f ".deps/memcheck_x86_linux-mac_shared.Tpo" ".deps/memcheck_x86_linux-mac_shared.Po"; else rm -f ".deps/memcheck_x86_linux-mac_shared.Tpo"; exit 1; fi
- if gcc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I../VEX/pub -DVGA_x86=1 -DVGO_linux=1 -DVGP_x86_linux=1 -m32 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -O2 -Wno-long-long -Wdeclaration-after-statement -MT memcheck_x86_linux-mc_translate.o -MD -MP -MF ".deps/memcheck_x86_linux-mc_translate.Tpo" -c -o memcheck_x86_linux-mc_translate.o `test -f 'mc_translate.c' || echo './'`mc_translate.c; \
- then mv -f ".deps/memcheck_x86_linux-mc_translate.Tpo" ".deps/memcheck_x86_linux-mc_translate.Po"; else rm -f ".deps/memcheck_x86_linux-mc_translate.Tpo"; exit 1; fi
- mc_translate.c: In function `expr2vbits_Binop':
- mc_translate.c:1909: error: `Iop_RoundF64' undeclared (first use in this function)
- mc_translate.c:1909: error: (Each undeclared identifier is reported only once
- mc_translate.c:1909: error: for each function it appears in.)
- mc_translate.c: In function `expr2vbits_Unop':
- mc_translate.c:2188: error: `Iop_Est8FRecip' undeclared (first use in this function)
- make[3]: *** [memcheck_x86_linux-mc_translate.o] Error 1
- make[3]: Leaving directory `/tmp/valgrind.13609/valgrind/memcheck'
- make[2]: *** [all-recursive] Error 1
- make[2]: Leaving directory `/tmp/valgrind.13609/valgrind/memcheck'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/tmp/valgrind.13609/valgrind'
- make: *** [all] Error 2
--- 3,22 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 242 tests, 9 stderr failures, 3 stdout failures =================
! memcheck/tests/amd64/insn_fpu (stdout)
! memcheck/tests/amd64/insn_fpu (stderr)
! memcheck/tests/stack_switch (stderr)
! memcheck/tests/x86/scalar (stderr)
! memcheck/tests/x86/scalar_supp (stderr)
! memcheck/tests/x86/sse1_memory (stdout)
! none/tests/amd64/faultstatus (stderr)
! none/tests/amd64/insn_fpu (stdout)
! none/tests/amd64/insn_fpu (stderr)
! none/tests/fdleak_fcntl (stderr)
! none/tests/x86/faultstatus (stderr)
! none/tests/x86/int (stderr)
|
--- trunk/memcheck/tests/x86/fprem.c 2006-02-04 15:26:11 UTC (rev 5609)
+++ trunk/memcheck/tests/x86/fprem.c 2006-02-04 15:43:14 UTC (rev 5610)
@@ -1,5 +1,6 @@
=20
-/* Marginally test fprem/fprem1; these are hard to check otherwise */
+/* Marginally test fprem/fprem1/fsincos; these are hard to check
+ otherwise since compilers hardly ever generate them. */
=20
#include <stdio.h>
=20
@@ -33,10 +34,24 @@
return res;
}
=20
+double do_fsincos ( void )
+{
+ double res;
+ __asm__ __volatile__(
+ "fldln2\n\t"
+ "fsincos\n\t"
+ "fsub %%st(1)\n\t"
+ "fstpl 0(%0)"
+ : : "r"(&res) =20
+ );
+ return res;
+}
+
int main ( void )
{
__asm__ __volatile__("finit");
- printf("fprem %f\n", do_fprem());
- printf("fprem1 %f\n", do_fprem1());
+ printf("fprem %f\n", do_fprem());
+ printf("fprem1 %f\n", do_fprem1());
+ printf("fsincos %f\n", do_fsincos());
return 0;
}
Modified: trunk/memcheck/tests/x86/fprem.stdout.exp
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/tests/x86/fprem.stdout.exp 2006-02-04 15:26:11 UTC (re=
v 5609)
+++ trunk/memcheck/tests/x86/fprem.stdout.exp 2006-02-04 15:43:14 UTC (re=
v 5610)
@@ -1,2 +1,3 @@
-fprem 0.693147
-fprem1 0.693147
+fprem 0.693147
+fprem1 0.693147
+fsincos 0.130278
|
|
From: <sv...@va...> - 2006-02-04 15:26:16
|
Author: sewardj
Date: 2006-02-04 15:26:11 +0000 (Sat, 04 Feb 2006)
New Revision: 5609
Log:
Yet more x86 instruction tests, mostly aimed at wierd/transcendental
x87 insns.
Added:
trunk/memcheck/tests/x86/fprem.c
trunk/memcheck/tests/x86/fprem.stderr.exp
trunk/memcheck/tests/x86/fprem.stdout.exp
trunk/memcheck/tests/x86/fprem.vgtest
trunk/memcheck/tests/x86/more_x86_fp.c
trunk/memcheck/tests/x86/more_x86_fp.stderr.exp
trunk/memcheck/tests/x86/more_x86_fp.stdout.exp
trunk/memcheck/tests/x86/more_x86_fp.vgtest
Modified:
trunk/memcheck/tests/x86/Makefile.am
Modified: trunk/memcheck/tests/x86/Makefile.am
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
--- trunk/memcheck/tests/x86/Makefile.am 2006-02-04 15:25:23 UTC (rev 560=
8)
+++ trunk/memcheck/tests/x86/Makefile.am 2006-02-04 15:26:11 UTC (rev 560=
9)
@@ -19,11 +19,14 @@
scalar_vfork.stderr.exp scalar_vfork.vgtest \
sse1_memory.stderr.exp sse1_memory.stdout.exp sse1_memory.vgtest \
sse2_memory.stderr.exp sse2_memory.stdout.exp sse2_memory.vgtest \
- tronical.stderr.exp tronical.vgtest
+ tronical.stderr.exp tronical.vgtest \
+ more_x86_fp.stderr.exp more_x86_fp.stdout.exp more_x86_fp.vgtest \
+ fprem.stderr.exp fprem.stdout.exp fprem.vgtest
=20
check_PROGRAMS =3D \
scalar_exit_group scalar_fork scalar_supp scalar_vfork \
- fpeflags pushfpopf scalar sse_memory tronical
+ fpeflags pushfpopf scalar sse_memory tronical \
+ more_x86_fp fprem
=20
AM_CPPFLAGS =3D -I$(top_srcdir)/include
AM_CFLAGS =3D $(WERROR) @FLAG_M32@ -Winline -Wall -Wshadow -g \
@@ -36,3 +39,4 @@
pushfpopf_SOURCES =3D pushfpopf_c.c pushfpopf_s.s
tronical_SOURCES =3D tronical.S
=20
+more_x86_fp_LDADD =3D -lm
Added: trunk/memcheck/tests/x86/fprem.c
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D